The following website given a fully introduction of this package:
https://docs.google.com/document/d/1tVRnCeYv3HvovK7V4Kn4B88EiWz5fmKiA_FgrsXdAAk/edit


If any problem or confusion about the explaination, please comment on above website or my github£º
https://github.com/moenova

For some real application of lazy-database you can find useful resources at here:
https://github.com/moenova/lazy-database-application